Class: Decidim::Results::Engine
- Inherits:
-
Rails::Engine
- Object
- Rails::Engine
- Decidim::Results::Engine
- Defined in:
- lib/decidim/results/engine.rb
Overview
This is the engine that runs on the public interface of decidim-results.
It mostly handles rendering the created results associated to a participatory
process.